Position

Struct Position 

pub struct Position {
    pub is_first: bool,
    pub is_last: bool,
}
The first component of the value yielded by WithPosition. Indicates the position of this element in the iterator results.

See .with_position() for more information.

Fields

is_first: bool

This is the initial element (also true if there’s exactly one element)

is_last: bool

This is the final element (also true if there’s exactly one element)

Implementations

Source

impl Position

pub fn is_exactly_one(self) -> bool

This is the first and the last element at the same time, and there are no more elements

pub fn is_middle(self) -> bool

This is neither first nor last element, and there will be more elements

pub fn is_first(self) -> bool

This is the initial element (also true if there’s exactly one element)

pub fn is_last(self) -> bool

This is the final element (also true if there’s exactly one element)