pub struct Position {
pub is_first: bool,
pub is_last: bool,
}Expand description
The first component of the value yielded by WithPosition.
Indicates the position of this element in the iterator results.
See .with_position() for more information.
Fields
is_first: boolThis is the initial element (also true if there’s exactly one element)
is_last: boolThis is the final element (also true if there’s exactly one element)
Implementations
Sourceimpl Position
impl Position
Sourcepub fn is_exactly_one(self) -> bool
pub fn is_exactly_one(self) -> bool
This is the first and the last element at the same time, and there are no more elements
Sourcepub fn is_middle(self) -> bool
pub fn is_middle(self) -> bool
This is neither first nor last element, and there will be more elements